==> kubernetes-model-1.0.62-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/ReplicaSetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.String;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;

public class ReplicaSetFluentImpl<A extends ReplicaSetFluent<A>> extends BaseFluent<A> implements ReplicaSetFluent<A>{

    private String apiVersion;
    private String kind;
    private VisitableBuilder<? extends ObjectMeta,?> metadata;
    private VisitableBuilder<? extends ReplicaSetSpec,?> spec;
    private VisitableBuilder<? extends ReplicaSetStatus,?> status;

    public ReplicaSetFluentImpl(){
    }
    public ReplicaSetFluentImpl(ReplicaSet instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public ReplicaSetFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ReplicaSetFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ReplicaSetFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ReplicaSetSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ReplicaSetSpec spec){
            if (spec!=null){ this.spec= new ReplicaSetSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public ReplicaSetFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public ReplicaSetFluent.SpecNested<A> withNewSpecLike(ReplicaSetSpec item){
            return new SpecNestedImpl(item);
    }

    public ReplicaSetFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public ReplicaSetStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(ReplicaSetStatus status){
            if (status!=null){ this.status= new ReplicaSetStatusBuilder(status); _visitables.add(this.status);} return (A) this;
    }

    public ReplicaSetFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public ReplicaSetFluent.StatusNested<A> withNewStatusLike(ReplicaSetStatus item){
            return new StatusNestedImpl(item);
    }

    public ReplicaSetFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public A withNewStatus(Integer fullyLabeledReplicas,Long observedGeneration,Integer replicas){
            return (A)withStatus(new ReplicaSetStatus(fullyLabeledReplicas, observedGeneration, replicas));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ReplicaSetFluentImpl that = (ReplicaSetFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ReplicaSetFluent.MetadataNested<N>> implements ReplicaSetFluent.MetadataNested<N>,Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ReplicaSetFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends ReplicaSetSpecFluentImpl<ReplicaSetFluent.SpecNested<N>> implements ReplicaSetFluent.SpecNested<N>,Nested<N>{

            private final ReplicaSetSpecBuilder builder;
    
            SpecNestedImpl(){
                    this.builder = new ReplicaSetSpecBuilder(this);
            }
            SpecNestedImpl(ReplicaSetSpec item){
                    this.builder = new ReplicaSetSpecBuilder(this, item);
            }
    
    public N endSpec(){
            return and();
    }
    public N and(){
            return (N) ReplicaSetFluentImpl.this.withSpec(builder.build());
    }

}
    public class StatusNestedImpl<N> extends ReplicaSetStatusFluentImpl<ReplicaSetFluent.StatusNested<N>> implements ReplicaSetFluent.StatusNested<N>,Nested<N>{

            private final ReplicaSetStatusBuilder builder;
    
            StatusNestedImpl(){
                    this.builder = new ReplicaSetStatusBuilder(this);
            }
            StatusNestedImpl(ReplicaSetStatus item){
                    this.builder = new ReplicaSetStatusBuilder(this, item);
            }
    
    public N and(){
            return (N) ReplicaSetFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}

==> kubernetes-model-1.0.65-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/ReplicaSetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import javax.validation.Valid;
import java.lang.Long;
import java.lang.Object;

public class ReplicaSetFluentImpl<A extends ReplicaSetFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ReplicaSetFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private ReplicaSetSpecBuilder spec;
    private ReplicaSetStatusBuilder status;

    public ReplicaSetFluentImpl(){
    }
    public ReplicaSetFluentImpl(ReplicaSet instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion!=null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind!=null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata!=null;
    }

    public ReplicaSetFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ReplicaSetFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ReplicaSetFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ReplicaSetFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ReplicaSetFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 */
@Deprecated public ReplicaSetSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public ReplicaSetSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(ReplicaSetSpec spec){
            _visitables.remove(this.spec);
            if (spec!=null){ this.spec= new ReplicaSetSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec!=null;
    }

    public ReplicaSetFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public ReplicaSetFluent.SpecNested<A> withNewSpecLike(ReplicaSetSpec item){
            return new SpecNestedImpl(item);
    }

    public ReplicaSetFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public ReplicaSetFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new ReplicaSetSpecBuilder().build());
    }

    public ReplicaSetFluent.SpecNested<A> editOrNewSpecLike(ReplicaSetSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    
/**
 * This method has been deprecated, please use method buildStatus instead.
 */
@Deprecated public ReplicaSetStatus getStatus(){
            return this.status!=null?this.status.build():null;
    }

    public ReplicaSetStatus buildStatus(){
            return this.status!=null?this.status.build():null;
    }

    public A withStatus(ReplicaSetStatus status){
            _visitables.remove(this.status);
            if (status!=null){ this.status= new ReplicaSetStatusBuilder(status); _visitables.add(this.status);} return (A) this;
    }

    public Boolean hasStatus(){
            return this.status!=null;
    }

    public ReplicaSetFluent.StatusNested<A> withNewStatus(){
            return new StatusNestedImpl();
    }

    public ReplicaSetFluent.StatusNested<A> withNewStatusLike(ReplicaSetStatus item){
            return new StatusNestedImpl(item);
    }

    public ReplicaSetFluent.StatusNested<A> editStatus(){
            return withNewStatusLike(getStatus());
    }

    public ReplicaSetFluent.StatusNested<A> editOrNewStatus(){
            return withNewStatusLike(getStatus() != null ? getStatus(): new ReplicaSetStatusBuilder().build());
    }

    public ReplicaSetFluent.StatusNested<A> editOrNewStatusLike(ReplicaSetStatus item){
            return withNewStatusLike(getStatus() != null ? getStatus(): item);
    }

    public A withNewStatus(Integer fullyLabeledReplicas,Long observedGeneration,Integer readyReplicas,Integer replicas){
            return (A)withStatus(new ReplicaSetStatus(fullyLabeledReplicas, observedGeneration, readyReplicas, replicas));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ReplicaSetFluentImpl that = (ReplicaSetFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ReplicaSetFluent.MetadataNested<N>> implements ReplicaSetFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ReplicaSetFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends ReplicaSetSpecFluentImpl<ReplicaSetFluent.SpecNested<N>> implements ReplicaSetFluent.SpecNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ReplicaSetSpecBuilder builder;
    
            SpecNestedImpl(ReplicaSetSpec item){
                    this.builder = new ReplicaSetSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new ReplicaSetSpecBuilder(this);
            }
    
    public N and(){
            return (N) ReplicaSetFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}
    public class StatusNestedImpl<N> extends ReplicaSetStatusFluentImpl<ReplicaSetFluent.StatusNested<N>> implements ReplicaSetFluent.StatusNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ReplicaSetStatusBuilder builder;
    
            StatusNestedImpl(ReplicaSetStatus item){
                    this.builder = new ReplicaSetStatusBuilder(this, item);
            }
            StatusNestedImpl(){
                    this.builder = new ReplicaSetStatusBuilder(this);
            }
    
    public N and(){
            return (N) ReplicaSetFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus(){
            return and();
    }

}


}
